@@ -152,6 +152,8 @@ void Forest::run(bool oobag){
 
 void Forest::init_trees(){
 
+ // Rcpp::Rcout << "when init trees called:" << std::endl << oobag_denom << std::endl;
+
  for(uword i = 0; i < n_tree; ++i){
 
   trees[i]->init(data.get(),
@@ -195,7 +197,9 @@ void Forest::grow() {
  if(n_thread == 1){
   // ensure safe usage of R functions and glmnet
   // by growing trees in a single thread.
-  grow_single_thread(&vi_numer, &vi_denom);
+  grow_single_thread(&oobag_denom,
+                     &vi_numer,
+                     &vi_denom);
   return;
  }
 
@@ -205,6 +209,7 @@ void Forest::grow() {
 
  // containers
  std::vector<std::thread> threads;
+ std::vector<vec> oobag_denom_threads(n_thread);
  std::vector<vec> vi_numer_threads(n_thread);
  std::vector<uvec> vi_denom_threads(n_thread);
 
@@ -214,10 +219,12 @@ void Forest::grow() {
  // begin multi-thread grow
  for (uint i = 0; i < n_thread; ++i) {
 
+  oobag_denom_threads[i].zeros(data->n_rows);
   vi_numer_threads[i].zeros(data->n_cols_x);
   if(vi_type == VI_ANOVA) vi_denom_threads[i].zeros(data->n_cols_x);
 
   threads.emplace_back(&Forest::grow_multi_thread, this, i,
+                       &(oobag_denom_threads[i]),
                        &(vi_numer_threads[i]),
                        &(vi_denom_threads[i]));
  }
@@ -237,6 +244,12 @@ void Forest::grow() {
   throw std::runtime_error("User interrupt.");
  }
 
+ for(uint i = 0; i < n_thread; ++i){
+  oobag_denom += oobag_denom_threads[i];
+ }
+
+ oobag_denom_threads.clear();
+
  if(vi_type == VI_ANOVA){
 
   for(uint i = 0; i < n_thread; ++i){
@@ -251,7 +264,8 @@ void Forest::grow() {
 
 }
 
-void Forest::grow_single_thread(vec* vi_numer_ptr,
+void Forest::grow_single_thread(vec* oobag_denom_ptr,
+                                vec* vi_numer_ptr,
                                 uvec* vi_denom_ptr){
 
 
@@ -271,7 +285,9 @@ void Forest::grow_single_thread(vec* vi_numer_ptr,
    Rcpp::Rcout << std::endl;
   }
 
-  trees[i]->grow(vi_numer_ptr, vi_denom_ptr);
+  // all three parameters were initialized in Forest::init,
+  // so initialization isn't needed here.
+  trees[i]->grow(oobag_denom_ptr, vi_numer_ptr, vi_denom_ptr);
 
   ++progress;
 
@@ -310,6 +326,7 @@ void Forest::grow_single_thread(vec* vi_numer_ptr,
 
 
 void Forest::grow_multi_thread(uint thread_idx,
+                               vec* oobag_denom_ptr,
                                vec* vi_numer_ptr,
                                uvec* vi_denom_ptr) {
 
@@ -318,7 +335,7 @@ void Forest::grow_multi_thread(uint thread_idx,
 
   for (uint i = thread_ranges[thread_idx]; i < thread_ranges[thread_idx + 1]; ++i) {
 
-   trees[i]->grow(vi_numer_ptr, vi_denom_ptr);
+   trees[i]->grow(oobag_denom_ptr, vi_numer_ptr, vi_denom_ptr);
 
    // Check for user interrupt
    if (aborted) {
@@ -516,19 +533,16 @@ std::vector<std::vector<arma::mat>> Forest::compute_dependence(bool oobag){
 
   std::vector<std::thread> threads;
   std::vector<std::vector<std::vector<mat>>> result_threads(n_thread);
-  std::vector<vec> oobag_denom_threads(n_thread);
 
   threads.reserve(n_thread);
 
   for (uint i = 0; i < n_thread; ++i) {
 
    resize_pd_mats(result_threads[i]);
-   if(oobag) oobag_denom_threads[i].zeros(data->n_rows);
 
    threads.emplace_back(&Forest::compute_dependence_multi_thread,
                         this, i, data.get(), oobag,
-                        std::ref(result_threads[i]),
-                        std::ref(oobag_denom_threads[i]));
+                        std::ref(result_threads[i]));
   }
 
   if(verbosity == 1){
@@ -584,13 +598,8 @@ void Forest::compute_dependence_single_thread(
  steady_clock::time_point last_time = steady_clock::now();
  size_t max_progress = n_tree;
 
- uword oobag_divby = 0;
  uword n_specs = pd_x_vals.size();
 
- for(uword k = 0; k < n_specs; ++k){
-  oobag_divby+=pd_x_vals[k].n_rows;
- }
-
  for (uint i = 0; i < n_tree; ++i) {
 
   if(verbosity > 1){
@@ -605,7 +614,7 @@ void Forest::compute_dependence_single_thread(
 
   trees[i] -> compute_dependence(prediction_data, result,
                                  pd_type, pd_x_vals, pd_x_cols,
-                                 oobag_denom, oobag);
+                                 oobag);
 
   progress++;
 
@@ -638,13 +647,6 @@ void Forest::compute_dependence_single_thread(
 
  }
 
- if(oobag){
-  oobag_denom /= oobag_divby;
-  if(verbosity > 3){
-   print_vec(oobag_denom, "oobag denom:", 5);
-  }
- }
-
  for(uword k = 0; k < n_specs; ++k){
   for(uword j = 0; j < pd_x_vals[k].n_rows; ++j){
    if(oobag){
@@ -661,24 +663,16 @@ void Forest::compute_dependence_multi_thread(
   uint thread_idx,
   Data* prediction_data,
   bool oobag,
-  std::vector<std::vector<arma::mat>>& result_ptr,
-  arma::vec& denom_ptr
+  std::vector<std::vector<arma::mat>>& result_ptr
 ){
 
- uword oobag_divby = 0;
- uword n_specs = pd_x_vals.size();
-
- for(uword k = 0; k < n_specs; ++k){
-  oobag_divby+=pd_x_vals[k].n_rows;
- }
-
  if (thread_ranges.size() > thread_idx + 1) {
 
   for (uint i = thread_ranges[thread_idx]; i < thread_ranges[thread_idx + 1]; ++i) {
 
    trees[i] -> compute_dependence(prediction_data, result_ptr,
                                   pd_type, pd_x_vals, pd_x_cols,
-                                  denom_ptr, oobag);
+                                  oobag);
 
    // Check for user interrupt
    if (aborted) {
@@ -697,11 +691,6 @@ void Forest::compute_dependence_multi_thread(
 
  }
 
- if(oobag){
-  denom_ptr /= oobag_divby;
-  oobag_denom += denom_ptr;
- }
-
 }
 
 mat Forest::predict(bool oobag) {
@@ -727,19 +716,16 @@ mat Forest::predict(bool oobag) {
 
   std::vector<std::thread> threads;
   std::vector<mat> result_threads(n_thread);
-  std::vector<vec> oobag_denom_threads(n_thread);
 
   threads.reserve(n_thread);
 
   for (uint i = 0; i < n_thread; ++i) {
 
    resize_pred_mat(result_threads[i], data->n_rows);
-   if(oobag) oobag_denom_threads[i].zeros(data->n_rows);
 
    threads.emplace_back(&Forest::predict_multi_thread,
                         this, i, data.get(), oobag,
-                        std::ref(result_threads[i]),
-                        std::ref(oobag_denom_threads[i]));
+                        std::ref(result_threads[i]));
   }
 
   if(verbosity == 1){
@@ -759,8 +745,6 @@ mat Forest::predict(bool oobag) {
 
    if(oobag){
 
-    oobag_denom += oobag_denom_threads[i];
-
     // evaluate oobag error after joining each thread
     // (only safe to do this when the condition below holds)
     if(grow_mode &&
@@ -779,7 +763,6 @@ mat Forest::predict(bool oobag) {
   }
 
   result_threads.clear();
-  oobag_denom_threads.clear();
 
  }
 
@@ -823,6 +806,8 @@ void Forest::predict_single_thread(Data* prediction_data,
  steady_clock::time_point last_time = steady_clock::now();
  size_t max_progress = n_tree;
 
+ // Rcpp::Rcout << "init oobag_denom" << std::endl << oobag_denom << std::endl;
+
  for (uint i = 0; i < n_tree; ++i) {
 
   if(verbosity > 1){
@@ -835,6 +820,7 @@ void Forest::predict_single_thread(Data* prediction_data,
    Rcpp::Rcout << std::endl;
   }
 
+
   trees[i]->predict_leaf(prediction_data, oobag);
 
   if(pred_type == PRED_TERMINAL_NODES){
@@ -844,12 +830,12 @@ void Forest::predict_single_thread(Data* prediction_data,
   } else if (!pred_aggregate){
 
    vec col_i = result.unsafe_col(i);
-   trees[i]->predict_value(col_i, oobag_denom, pred_type, oobag);
+   trees[i]->predict_value(col_i, pred_type, oobag);
 
 
   } else {
 
-   trees[i]->predict_value(result, oobag_denom, pred_type, oobag);
+   trees[i]->predict_value(result, pred_type, oobag);
 
   }
 
@@ -882,6 +868,8 @@ void Forest::predict_single_thread(Data* prediction_data,
 
   }
 
+  // Rcpp::Rcout << "oobag_denom: progress of " << progress << std::endl << oobag_denom << std::endl;
+
   // if tracking oobag error over time:
   if(oobag && grow_mode && (progress%oobag_eval_every==0) && pred_aggregate){
 
@@ -899,8 +887,7 @@ void Forest::predict_single_thread(Data* prediction_data,
 void Forest::predict_multi_thread(uint thread_idx,
                                   Data* prediction_data,
                                   bool oobag,
-                                  mat& result_ptr,
-                                  vec& denom_ptr) {
+                                  mat& result_ptr) {
 
  if (thread_ranges.size() > thread_idx + 1) {
 
@@ -915,11 +902,11 @@ void Forest::predict_multi_thread(uint thread_idx,
    } else if (!pred_aggregate){
 
     vec col_i = result_ptr.unsafe_col(i);
-    trees[i]->predict_value(col_i, denom_ptr, pred_type, oobag);
+    trees[i]->predict_value(col_i, pred_type, oobag);
 
    } else {
 
-    trees[i]->predict_value(result_ptr, denom_ptr, pred_type, oobag);
+    trees[i]->predict_value(result_ptr, pred_type, oobag);
 
    }
 
