@@ -67,15 +67,45 @@ aorsf may be modified and distributed under the terms of the MIT license.
                         arma::vec& w,
                         arma::uvec& g);
 
- double compute_cstat(arma::mat& y,
-                      arma::vec& w,
-                      arma::vec& p,
-                      bool pred_is_risklike);
+ double compute_cstat_surv(arma::mat& y,
+                           arma::vec& w,
+                           arma::vec& p,
+                           bool pred_is_risklike);
 
- double compute_cstat(arma::mat& y,
-                      arma::vec& w,
-                      arma::uvec& g,
-                      bool pred_is_risklike);
+ double compute_cstat_surv(arma::mat& y,
+                           arma::vec& w,
+                           arma::uvec& g,
+                           bool pred_is_risklike);
+
+ double compute_cstat_clsf(arma::vec& y,
+                           arma::vec& w,
+                           arma::vec& p);
+
+ double compute_cstat_clsf(arma::vec& y,
+                           arma::vec& w,
+                           arma::uvec& g);
+
+ double compute_mse(arma::vec& y,
+                    arma::vec& w,
+                    arma::vec& p);
+
+ double compute_rsq(arma::vec& y,
+                    arma::vec& w,
+                    arma::vec& p);
+
+ double compute_gini(arma::mat& y,
+                     arma::vec& w,
+                     arma::uvec& g);
+
+ double compute_var_reduction(arma::vec& y,
+                              arma::vec& w,
+                              arma::uvec& g);
+
+ arma::vec compute_pred_prob(arma::mat& y,
+                             arma::vec& w);
+
+ double compute_pred_mean(arma::mat& y,
+                          arma::vec& w);
 
  arma::mat linreg_fit(arma::mat& x_node,
                       arma::mat& y_node,
@@ -94,8 +124,12 @@ aorsf may be modified and distributed under the terms of the MIT license.
  arma::mat scale_x(arma::mat& x,
                    arma::vec& w);
 
- void unscale_x(arma::mat& x,
-                arma::mat& x_transforms);
+ void unscale_outputs(arma::mat& x,
+                      arma::vec& beta,
+                      arma::vec& beta_var,
+                      arma::mat& x_transforms);
+
+ void predict_class(arma::mat& pred);
 
  }
 
